@@ -63,7 +63,8 @@
 #' \code{BeginTSP}, \code{LengthTSP} and then \code{EndTSP} is estimated using \code{BeginTSP} + \code{abs(LengthTSP)}\cr
 #' \code{DHA}, \code{DHH}, \code{T12H} are the SSM parameters of sexualisation thermal reaction norm; \cr
 #' \code{dbeta_mu}, \code{dbeta_v} are the beta mean and variance of the impact of sexualisation according to TSP progress.\cr
-#' Or any parameter that can be used in a TSD model.
+#' Or any parameter that can be used in a TSD model.\cr
+#' If parameters of tsd model are provided in Initial_STRN, the equation parameter must be setup. See ?tsd
 #' @examples
 #' \dontrun{
 #' library(embryogrowth)
@@ -222,7 +223,7 @@ STRN <- function(EmbryoGrowthTRN=stop("Embryo Growth Thermal Reaction Norm must
                  TSP.begin=0                                                                 , 
                  TSP.end=0.5                                                                 , 
                  tsd=NULL                                                                    ,
-                 equation="logistic"                                                         , 
+                 equation=NULL                                                               , 
                  Sexed=NULL                                                                  , 
                  Males=NULL                                                                  , 
                  Females=NULL                                                                , 
