@@ -9,7 +9,7 @@
 #' @param derivate Function used to fit embryo growth: derivate.Gompertz, derivate.exponential or derivate.linear
 #' @param hatchling.metric A vector with Mean and SD of size of hatchlings, ex. hatchling.metric=c(Mean=39, SD=3). Can be a data.frame also. See description
 #' @param M0 Measure of hatchling size or mass proxi at laying date
-#' @param saveAtMaxiter If True, each time number of interation reach maxiter, current data are saved in file with filename name
+#' @param saveAtMaxiter If TRUE, each time number of interation reach maxiter, current data are saved in file with filename name
 #' @param fileName The intermediate results are saved in file with fileName.Rdata name
 #' @param weight A named vector of the weight for each nest for likelihood estimation
 #' @param control List for control parameters for optimx
@@ -381,14 +381,14 @@ searchR <- function(parameters=stop('Initial set of parameters must be provided'
                     fixed.parameters=c(rK=1.208968)                              , 
                     integral=integral.Gompertz                                   , 
                     derivate=NULL                                                , 
-                    hatchling.metric=c(Mean=39.33, SD=1.92)                      , 
-                    M0=0.3470893                                                 , 
+                    hatchling.metric=NULL                                        , 
+                    M0=NULL                                                      , 
                     saveAtMaxiter=FALSE                                          , 
                     fileName="intermediate"                                      , 
                     weight=NULL                                                  , 
                     control=list(trace=1, REPORT=100, maxit=500)                 ) {
   
-  # parameters=NULL; fixed.parameters=NULL; temperatures=NULL; integral=integral.Gompertz; derivate=NULL; hatchling.metric=c(Mean=39.33, SD=1.92); M0=1.7; saveAtMaxiter=FALSE; fileName="intermediate"; weight=NULL; SE=FALSE; control=list(trace=1, REPORT=100, maxit=500)  # temperatures <- formated
+  # parameters=NULL; fixed.parameters=NULL; temperatures=NULL; integral=integral.Gompertz; derivate=NULL; hatchling.metric=NULL; M0=NULL; saveAtMaxiter=FALSE; fileName="intermediate"; weight=NULL; SE=FALSE; control=list(trace=1, REPORT=100, maxit=500)  # temperatures <- formated
   
   # parameters=x; fixed.parameters=pfixed; temperatures=formated; integral=integral.Gompertz; M0=1.7; hatchling.metric=c(Mean=39.33, SD=1.92)
   
